@@ -1,6 +1,6 @@
-__version__ = '0.1.1'
+__version__ = '0.2.1'
 
-from multiprocessing import Process, active_children, cpu_count
+from multiprocessing import Process, active_children, cpu_count, Pipe
 import os
 import signal
 import sys
@@ -15,11 +15,12 @@ except NotImplementedError:
     DEFAULT_CPU = 1
 
 
-def loop():
-    print "Process ID:", os.getpid()
+def loop(conn):
+    proc_info = os.getpid()
+    conn.send(proc_info)
+    conn.close()
     while True:
         fib(FIB_N)
-    return c
 
 
 def fib(n):
@@ -38,6 +39,7 @@ def sigint_handler(signum, frame):
 
 signal.signal(signal.SIGINT, sigint_handler)
 
+
 def get_args():
     exec_time = DEFAULT_TIME
     proc_num = DEFAULT_CPU
@@ -51,6 +53,7 @@ def get_args():
 
     return exec_time, proc_num
 
+
 def _main():
     try:
         exec_time, proc_num = get_args()
@@ -59,13 +62,22 @@ def _main():
         sys.stderr.write(msg)
         sys.exit(1)
     procs = []
+    conns = []
     for i in range(proc_num):
-        p = Process(target=loop)
+        parent_conn, child_conn = Pipe()
+        p = Process(target=loop, args=(child_conn,))
         p.start()
         procs.append(p)
+        conns.append(parent_conn)
+
+    for conn in conns:
+        try:
+            print conn.recv()
+        except EOFError:
+            continue
 
     time.sleep(exec_time)
-    
+
     for p in procs:
         p.terminate()
 
